@@ -8,8 +8,7 @@ use Path::Tiny qw( path );
 use Capture::Tiny qw( capture_stderr );
 
 # ABSTRACT: Private legacy pkg-config class for Alien::Base
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.20'; # VERSION
 
 
 sub new {
@@ -47,10 +46,10 @@ sub read {
   open my $fh, '<', $path
     or croak "Cannot open .pc file $path: $!";
 
-  while (my $line = <$fh>) {
-    if ($line =~ /^([^=:]+?)=([^\n\r]*)/) {
+  while (<$fh>) {
+    if (/^([^=:]+?)=([^\n\r]*)/) {
       $self->{vars}{$1} = $2;
-    } elsif ($line =~ /^([^=:]+?):\s*([^\n\r]*)/) {
+    } elsif (/^([^=:]+?):\s*([^\n\r]*)/) {
       $self->{keywords}{$1} = $2;
     }
   }
@@ -73,7 +72,7 @@ sub make_abstract {
   my ($var, $value) = @_;
 
   $value = defined $value ? $value : $self->{vars}{$var};
-
+    
   # convert other vars
   foreach my $key (keys %{ $self->{vars} }) {
     next if $key eq $var; # don't overwrite the current var
@@ -94,7 +93,7 @@ sub _interpolate_vars {
   $override ||= {};
 
   foreach my $key (keys %$override) {
-    carp "Overriden pkg-config variable $key, contains no data"
+    carp "Overriden pkg-config variable $key, contains no data" 
       unless $override->{$key};
   }
 
@@ -107,7 +106,7 @@ sub _interpolate_vars {
 sub keyword {
   my $self = shift;
   my ($keyword, $override) = @_;
-
+  
   {
     no warnings 'uninitialized';
     croak "overrides passed to 'keyword' must be a hashref"
@@ -122,7 +121,7 @@ my $pkg_config_command;
 sub pkg_config_command {
   unless (defined $pkg_config_command) {
     capture_stderr {
-
+    
       # For now we prefer PkgConfig.pm over pkg-config on
       # Solaris 64 bit Perls.  We may need to do this on
       # other platforms, in which case this logic should
@@ -137,7 +136,7 @@ sub pkg_config_command {
       }
     }
   }
-
+  
   $pkg_config_command;
 }
 
@@ -163,14 +162,14 @@ Alien::Base::PkgConfig - Private legacy pkg-config class for Alien::Base
 
 =head1 VERSION
 
-version 1.99_01
+version 1.20
 
 =head1 DESCRIPTION
 
 This class is used internally by L<Alien::Base> and L<Alien::Base::ModuleBuild>
 to store information from pkg-config about installed Aliens.  It is not used
 internally by the newer L<alienfile> and L<Alien::Build>.  It should never
-be used externally, should not be used for code new inside of C<Alien-Build>.
+be used externally, should not be used for new inside of C<Alien-Build>.
 
 =head1 SEE ALSO
 
@@ -192,7 +191,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -228,23 +227,9 @@ Joel Berger (JBERGER)
 
 Petr Pisar (ppisar)
 
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
