@@ -8,7 +8,7 @@ use Capture::Tiny qw( capture );
 use Carp ();
 
 # ABSTRACT: Alien::Build installer code for ExtUtils::MakeMaker
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 sub new
@@ -17,13 +17,22 @@ sub new
   
   my $self = bless {}, $class;
   
+  my %meta = map { $_ => $prop{$_} } grep /^my_/, keys %prop;
+
   my $build = $self->{build} =
     Alien::Build->load('alienfile',
       root     => "_alien",
       (-d 'patch' ? (patch => 'patch') : ()),
+      meta_prop => \%meta,
     )
   ;
   
+  if(%meta)
+  {
+    $build->meta->add_requires(configure => 'Alien::Build::MM' => '1.20');
+    $build->meta->add_requires(configure => 'Alien::Build' => '1.20');
+  }
+  
   if(defined $prop{alienfile_meta})
   {
     $self->{alienfile_meta} = $prop{alienfile_meta};
@@ -344,7 +353,7 @@ Alien::Build::MM - Alien::Build installer code for ExtUtils::MakeMaker
 
 =head1 VERSION
 
-version 1.18
+version 1.20
 
 =head1 SYNOPSIS
 
