@@ -7,7 +7,7 @@ use File::Which ();
 use Env qw( @PATH );
 
 # ABSTRACT: MSYS plugin for Alien::Build
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 has msys_version   => '0.07';
@@ -80,12 +80,12 @@ Alien::Build::Plugin::Build::MSYS - MSYS plugin for Alien::Build
 
 =head1 VERSION
 
-version 1.18
+version 1.20
 
 =head1 SYNOPSIS
 
  use alienfile;
- plugin 'Build::MSYS' => ();
+ plugin 'Build::MSYS';
 
 =head1 DESCRIPTION
 
