@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use File::Basename ();
 
 # ABSTRACT: Plugin to extract links from a directory listing
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 sub init
@@ -58,12 +58,12 @@ Alien::Build::Plugin::Decode::DirListing - Plugin to extract links from a direct
 
 =head1 VERSION
 
-version 1.18
+version 1.20
 
 =head1 SYNOPSIS
 
  use alienfile;
- plugin 'Decode::DirListing' => ();
+ plugin 'Decode::DirListing';
 
 =head1 DESCRIPTION
 
