@@ -8,120 +8,73 @@ use File::Which qw( which );
 use Path::Tiny qw( path );
 use Capture::Tiny qw( capture );
 use File::Temp qw( tempdir );
-use List::Util 1.33 qw( any );
 use File::chdir;
 
-# ABSTRACT: Plugin for fetching files using curl
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: Curl command line plugin for fetching files
+our $VERSION = '1.20'; # VERSION
 
 
-sub curl_command
-{
-  defined $ENV{CURL} ? scalar which($ENV{CURL}) : scalar which('curl');
-}
-
+has curl_command => sub { defined $ENV{CURL} ? which($ENV{CURL}) : which('curl') };
 has ssl => 0;
 has _see_headers => 0;
-has '+url' => '';
-
-# when bootstrapping we have to specify this plugin as a prereq
-# 1 is the default so that when this plugin is used directly
-# you also get the prereq
-has bootstrap_ssl => 1;
-
-
-sub protocol_ok
-{
-  my($class, $protocol) = @_;
-  my $curl = $class->curl_command;
-  return 0 unless defined $curl;
-  my($out, $err, $exit) = capture {
-    system $curl, '--version';
-  };
-
-  {
-    # make sure curl supports the -J option.
-    # CentOS 6 for example is recent enough
-    # that it does not.  gh#147, gh#148, gh#149
-    local $CWD = tempdir( CLEANUP => 1 );
-    my $file1 = path('foo/foo.txt');
-    $file1->parent->mkpath;
-    $file1->spew("hello world\n");
-    my $url = 'file://' . $file1->absolute;
-    my($out, $err, $exit) = capture {
-      system $curl, '-O', '-J', $url;
-    };
-    my $file2 = $file1->parent->child($file1->basename);
-    unlink "$file1";
-    unlink "$file2";
-    rmdir($file1->parent);
-    return 0 if $exit;
-  }
-
-  foreach my $line (split /\n/, $out)
-  {
-    if($line =~ /^Protocols:\s*(.*)\s*$/)
-    {
-      my %proto = map { $_ => 1 } split /\s+/, $1;
-      return $proto{$protocol} if $proto{$protocol};
-    }
-  }
-  return 0;
-}
 
 sub init
 {
   my($self, $meta) = @_;
 
-  $meta->prop->{start_url} ||= $self->url;
-  $self->url($meta->prop->{start_url});
-  $self->url || Carp::croak('url is a required property');
-
-  $meta->add_requires('configure', 'Alien::Build::Plugin::Fetch::CurlCommand' => '1.19')
-    if $self->bootstrap_ssl;
+  $meta->add_requires('configure', 'Alien::Build::Plugin::Fetch::CurlCommand' => '1.19');
 
   $meta->register_hook(
     fetch => sub {
       my($build, $url) = @_;
-      $url ||= $self->url;
+      $url ||= $meta->prop->{start_url};
 
       my($scheme) = $url =~ /^([a-z0-9]+):/i;
-
+      
       if($scheme =~ /^https?$/)
       {
         local $CWD = tempdir( CLEANUP => 1 );
-
-        my @writeout = (
-          "ab-filename     :%{filename_effective}",
-          "ab-content_type :%{content_type}",
-          "ab-url          :%{url_effective}",
+      
+        path('writeout')->spew(
+          join("\\n",
+            "ab-filename     :%{filename_effective}",
+            "ab-content_type :%{content_type}",
+            "ab-url          :%{url_effective}",
+          ),
         );
-
-        $build->log("writeout: $_\\n") for @writeout;
-        path('writeout')->spew(join("\\n", @writeout));
-
+      
         my @command = (
           $self->curl_command,
-          '-L', '-f', '-O', '-J',
+          '-L', '-f', -o => 'content',
           -w => '@writeout',
         );
-
+      
         push @command, -D => 'head' if $self->_see_headers;
-
+      
         push @command, $url;
-
+      
         my($stdout, $stderr) = $self->_execute($build, @command);
 
-        my %h = map { /^ab-(.*?)\s*:(.*)$/ ? ($1 => $2) : () } split /\n/, $stdout;
+        my %h = map { my($k,$v) = m/^ab-(.*?)\s*:(.*)$/; $k => $v } split /\n/, $stdout;
+
+        if($h{url} =~ m{/([^/]+)$})
+        {
+          $h{filename} = $1;
+        }
+        else
+        {
+          $h{filename} = 'index.html';
+        }
+        
+        rename 'content', $h{filename};
 
         if(-e 'head')
         {
           $build->log(" ~ $_ => $h{$_}") for sort keys %h;
           $build->log(" header: $_") for path('headers')->lines;
         }
-
-        my($type) = split /;/, $h{content_type};
+      
+        my($type) = split ';', $h{content_type};
 
         if($type eq 'text/html')
         {
@@ -161,6 +114,7 @@ sub init
 #
 #          my($filename) = $url =~ m{/([^/]+)$};
 #          $filename = 'unknown' if (! defined $filename) || ($filename eq '');
+#          $DB::single = 1;
 #          my($stdout, $stderr) = eval { $self->_execute($build, $self->curl_command, -o => $filename, $url) };
 #          $first_error = $@;
 #          if($first_error eq '')
@@ -172,7 +126,7 @@ sub init
 #            };
 #          }
 #        }
-#
+#        
 #        {
 #          my($stdout, $stderr) = eval { $self->_execute($build, $self->curl_command, -l => "$url/") };
 #          if($@ eq '')
@@ -195,11 +149,11 @@ sub init
       {
         die "scheme $scheme is not supported by the Fetch::CurlCommand plugin";
       }
-
+      
     },
   ) if $self->curl_command;
-
-  $self;
+  
+  $self;  
 }
 
 sub _execute
@@ -213,15 +167,8 @@ sub _execute
   if($err)
   {
     chomp $stderr;
-    $build->log($_) for split /\n/, $stderr;
-    if($stderr =~ /Remote filename has no length/ && !!(any { /^-O$/ } @command))
-    {
-      my @new_command = map {
-        /^-O$/ ? ( -o => 'index.html' ) : /^-J$/ ? () : ($_)
-      } @command;
-      return $self->_execute($build, @new_command);
-    }
-    die "error in curl fetch";
+    $stderr = [split /\n/, $stderr]->[-1];
+    die "error in curl fetch: $stderr";
   }
   ($stdout, $stderr);
 }
@@ -236,11 +183,11 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Fetch::CurlCommand - Plugin for fetching files using curl
+Alien::Build::Plugin::Fetch::CurlCommand - Curl command line plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -253,6 +200,8 @@ version 1.99_01
 
 =head1 DESCRIPTION
 
+B<WARNING>: This plugin is somewhat experimental at this time.
+
 This plugin provides a fetch based on the C<curl> command.  It works with other fetch
 plugins (that is, the first one which succeeds will be used).  Most of the time the best plugin
 to use will be L<Alien::Build::Plugin::Download::Negotiate>, but for some SSL bootstrapping
@@ -260,8 +209,6 @@ it may be desirable to try C<curl> first.
 
 Protocols supported: C<http>, C<https>
 
-C<https> support requires that curl was built with SSL support.
-
 =head1 PROPERTIES
 
 =head2 curl_command
@@ -272,13 +219,6 @@ The full path to the C<curl> command.  The default is usually correct.
 
 Ignored by this plugin.  Provided for compatibility with some other fetch plugins.
 
-=head1 METHODS
-
-=head2 protocol_ok
-
- my $bool = $plugin->protocol_ok($protocol);
- my $bool = Alien::Build::Plugin::Fetch::CurlCommand->protocol_ok($protocol);
-
 =head1 SEE ALSO
 
 =over 4
@@ -297,7 +237,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -333,23 +273,9 @@ Joel Berger (JBERGER)
 
 Petr Pisar (ppisar)
 
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
