@@ -7,7 +7,7 @@ use File::Basename ();
 use Carp ();
 
 # ABSTRACT: LWP plugin for fetching files
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 has '+url' => '';
@@ -98,13 +98,15 @@ Alien::Build::Plugin::Fetch::HTTPTiny - LWP plugin for fetching files
 
 =head1 VERSION
 
-version 1.18
+version 1.20
 
 =head1 SYNOPSIS
 
  use alienfile;
- meta->prop->{start_url} = 'http://ftp.gnu.org/gnu/make';
- plugin 'Fetch::HTTPTiny' => ();
+ share {
+   start_url 'http://ftp.gnu.org/gnu/make';
+   plugin 'Fetch::HTTPTiny';
+ };
 
 =head1 DESCRIPTION
 
