@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: LWP plugin for fetching files
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 has '+url' => '';
@@ -89,13 +89,15 @@ Alien::Build::Plugin::Fetch::LWP - LWP plugin for fetching files
 
 =head1 VERSION
 
-version 1.18
+version 1.20
 
 =head1 SYNOPSIS
 
  use alienfile;
- meta->prop->{start_url} = 'http://ftp.gnu.org/gnu/make';
- plugin 'Fetch::LWP' => ();
+ share {
+   start_url 'http://ftp.gnu.org/gnu/make';
+   plugin 'Fetch::LWP';
+ };
 
 =head1 DESCRIPTION
 
