@@ -7,7 +7,7 @@ use File::chdir;
 use Path::Tiny ();
 
 # ABSTRACT: Local directory plugin for fetching files
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 has root => undef;
@@ -91,13 +91,15 @@ Alien::Build::Plugin::Fetch::LocalDir - Local directory plugin for fetching file
 
 =head1 VERSION
 
-version 1.18
+version 1.20
 
 =head1 SYNOPSIS
 
  use alienfile;
- meta->prop->{start_url} = 'patch/libfoo-1.00/';
- plugin 'Fetch::LocalDir';
+ share {
+   start_url 'patch/libfoo-1.00/';
+   plugin 'Fetch::LocalDir';
+ };
 
 =head1 DESCRIPTION
 
