@@ -10,24 +10,17 @@ use Capture::Tiny qw( capture );
 use File::chdir;
 
 # ABSTRACT: Plugin for fetching files using wget
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.20'; # VERSION
 
 
 has wget_command => sub { defined $ENV{WGET} ? which($ENV{WGET}) : which('wget') };
 has ssl => 0;
 
-# when bootstrapping we have to specify this plugin as a prereq
-# 1 is the default so that when this plugin is used directly
-# you also get the prereq
-has bootstrap_ssl => 1;
-
 sub init
 {
   my($self, $meta) = @_;
-
-  $meta->add_requires('configure', 'Alien::Build::Plugin::Fetch::Wget' => '1.19')
-    if $self->bootstrap_ssl;
+  
+  $meta->add_requires('configure', 'Alien::Build::Plugin::Fetch::Wget' => '1.19');
 
   $meta->register_hook(
     fetch => sub {
@@ -35,11 +28,11 @@ sub init
       $url ||= $meta->prop->{start_url};
 
       my($scheme) = $url =~ /^([a-z0-9]+):/i;
-
+      
       if($scheme eq 'http' || $scheme eq 'https')
       {
         local $CWD = tempdir( CLEANUP => 1 );
-
+        
         my($stdout, $stderr) = $self->_execute(
           $build,
           $self->wget_command,
@@ -107,7 +100,7 @@ Alien::Build::Plugin::Fetch::Wget - Plugin for fetching files using wget
 
 =head1 VERSION
 
-version 1.99_01
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -157,7 +150,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -193,23 +186,9 @@ Joel Berger (JBERGER)
 
 Petr Pisar (ppisar)
 
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
