@@ -5,17 +5,14 @@ use warnings;
 use Carp ();
 use base qw( Exporter );
 use overload
-  '<=>'    => sub { shift->cmp(@_) },
-  'cmp'    => sub { shift->cmp(@_) },
-  '""'     => sub { shift->as_string },
-  bool     => sub { 1 },
-  fallback => 1;
+  '<=>' => sub { shift->cmp(@_) },
+  'cmp' => sub { shift->cmp(@_) },
+  '""'  => sub { shift->as_string };
 
 our @EXPORT_OK = qw( version );
 
 # ABSTRACT: Very basic version object for Alien::Build
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.20'; # VERSION
 
 
 sub new
@@ -44,16 +41,16 @@ sub as_string
 
 sub cmp
 {
-  my @x = split /\./, ${$_[0]};
-  my @y = split /\./, ${ref($_[1]) ? $_[1] : version($_[1])};
-
-  while(@x or @y)
+  my @a = split /\./, ${$_[0]};
+  my @b = split /\./, ${ref($_[1]) ? $_[1] : version($_[1])};
+  
+  while(@a or @b)
   {
-    my $x = (shift @x) || 0;
-    my $y = (shift @y) || 0;
-    return $x <=> $y if $x <=> $y;
+    my $a = (shift @a) || 0;
+    my $b = (shift @b) || 0;
+    return $a <=> $b if $a <=> $b;
   }
-
+  
   0;
 }
 
@@ -72,7 +69,7 @@ Alien::Build::Version::Basic - Very basic version object for Alien::Build
 
 =head1 VERSION
 
-version 1.99_01
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -187,7 +184,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -223,23 +220,9 @@ Joel Berger (JBERGER)
 
 Petr Pisar (ppisar)
 
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
